# django_app_novadata
Example of PyPI package.
## Getting Started
#### Dependencies
You need Python 3.6 or later to use **pacotepypi**. You can find it at [python.org](https://www.python.org/).
You also need setuptools, wheel and twine packages, which is available from [PyPI](https://pypi.org). If you have pip, just run:
```
pip install setuptools
pip install wheel
pip install twine
```
#### Installation
Clone this repo to your local machine using:
```
git clone https://github.com/TimeNovaData/django_novadata.git
```
